==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/elements/vtcre1.f <==
      SUBROUTINE VTCRE1(CHAMP,NUMEDD,CLASSE,TYPE,IFM,NIV,METHOD,SDFETI,
     &                  NUMSD,NEQ)
C-----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 22/11/2004   AUTEUR BOITEAU O.BOITEAU 
C ======================================================================
C COPYRIGHT (C) 1991 - 2004  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C-----------------------------------------------------------------------
C    - FONCTION REALISEE:  CREATION DES OBJETS JEVEUX DE LA STRUCTURE
C      DE DONNEES CHAMNO. UTILITAIRE DE BAS NIVEAU LANCE PAR VTCREB.
C
C     IN  CHAMP  : K24 : NOM DU CHAM_NO A CREER
C     IN  NUMEDD : K24 : PROF_CHNO DU CHAM_NO
C     IN  CLASSE : K1  : NOM DE LA BASE SUR LAQUELLE LE CHAM_NO DOIT
C                        ETRE CREE
C     IN  TYPCE  : K1  : TYPE DES VALEURS DU CHAM_NO A CREER
C                  'R'    ==> COEFFICIENTS REELS
C                  'C'    ==> COEFFICIENTS COMPLEXES
C     IN IFM,NIV : I   : PARAMETRES POUR MONITORING.
C     IN NUMSD   : I   : NUMERO DE SOUS-DOAMINE
C     OUT METHOD,SDFETI: K24 : PARAMETRES DU SOLVEUR.
C     OUT   NEQ   : I   : INTEGER
C   -------------------------------------------------------------------
C     SUBROUTINES APPELLEES:
C       DIVERS: DISMOI,SDCHGD,UTIMSD.
C       JEVEUX:JEMARQ,JEDEMA,WKVECT,JEVEUO,JEECRA.
C
C     FONCTIONS INTRINSEQUES:
C       NONE.
C   -------------------------------------------------------------------
C     ASTER INFORMATIONS:
C       25/11/03 (OB): CREATION.
C----------------------------------------------------------------------
C RESPONSABLE BOITEAU O.BOITEAU
C CORPS DU PROGRAMME
      IMPLICIT NONE

C DECLARATION PARAMETRES D'APPELS
      CHARACTER*1  CLASSE,TYPE
      CHARACTER*24 CHAMP,NUMEDD,METHOD,SDFETI
      INTEGER      NUMSD,NEQ

C --- DEBUT DECLARATIONS NORMALISEES JEVEUX ----------------
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C --- FIN DECLARATIONS NORMALISEES JEVEUX --------------------

C DECLARATION VARIABLES LOCALES
      INTEGER      JCHAMP,JREFN,IBID,IERD,JNEQ,LCHP,NBREFN,
     &             IFM,NIV,IINF
      CHARACTER*8  K8BID
      CHARACTER*24 VALE,REFE,DESC,INFOFE

      DATA VALE/'                   .VALE'/
      DATA REFE/'                   .REFE'/
      DATA DESC/'                   .DESC'/
            
C------------------------------------------------------------------
      CALL JEMARQ()
      INFOFE='FFFFFFFF'

C ------------------------------- REFE --------------------------------
C --- AFFECTATION DES INFORMATIONS DE REFERENCE A CHAMP

C ON ETOFFE L'OBJET .REFE DU CHAMNO AVEC LE TYPE DE RESOLUTION ET LE
C NOM DE LA SD_FETI PRIS DANS LE .REFN DU NUME_DDL SOUS-JACENT

      CALL JEVEUO(NUMEDD(1:14)//'.NUME.REFN','L',JREFN)
      REFE(1:19) = CHAMP 
           
C NUME_DDL ET DONC CHAM_NO ETENDU, OUI OU NON ?      
      CALL JELIRA(NUMEDD(1:14)//'.NUME.REFN','LONMAX',NBREFN,K8BID)
      IF (NBREFN.NE.4) THEN
        IF (NIV.GE.2) WRITE(IFM,*)
     &       '<FETI/VTCRE1> NUME_DDL/CHAM_NO NON ETENDU POUR FETI',
     &       NUMEDD(1:14)//'.NUME.REFN'      
        METHOD='XXXX'
        SDFETI='XXXX'
        CALL WKVECT(REFE,CLASSE//' V K24',2,JCHAMP)                     
      ELSE
        CALL WKVECT(REFE,CLASSE//' V K24',4,JCHAMP)
        METHOD = ZK24(JREFN+2)
        SDFETI = ZK24(JREFN+3)
        ZK24(JCHAMP+2) = METHOD
        ZK24(JCHAMP+3) = SDFETI
        IF ((METHOD(1:4).EQ.'FETI').OR.(NUMSD.GT.0)) THEN
          CALL JEVEUO('&&'//SDFETI(1:17)//'.FINF','L',IINF)
          INFOFE=ZK24(IINF)
        ENDIF         
      ENDIF
      ZK24(JCHAMP) = ZK24(JREFN)
      ZK24(JCHAMP+1) = NUMEDD(1:14)//'.NUME'      
      
C ------------------------------- DESC --------------------------------
C --- AFFECTATION DES INFORMATIONS DE REFERENCE A CHAMP

      DESC(1:19) = CHAMP
      CALL WKVECT(DESC,CLASSE//' V I',2,JCHAMP)
      CALL JEECRA(DESC,'DOCU',IBID,'CHNO')
      CALL DISMOI('F','NUM_GD_SI',NUMEDD,'NUME_DDL',ZI(JCHAMP),
     &            K8BID,IERD)
      ZI(JCHAMP+1) = 1

C ------------------------------- VALE --------------------------------
C --- CREATION DE L'OBJET SIMPLE DES VALEURS
C --- TYPE DES VALEURS, LONGUEUR D'UN VECTEUR

      CALL JEVEUO(NUMEDD(1:14)//'.NUME.NEQU','L',JNEQ)
      NEQ = ZI(JNEQ)
      VALE(1:19) = CHAMP
      CALL JECREO(VALE,CLASSE//' V '//TYPE)
      CALL JEECRA(VALE,'LONMAX',NEQ,K8BID)
      CALL JEVEUO(VALE,'E',LCHP)

C --- CHANGER LA GRANDEUR
      CALL SDCHGD(CHAMP,TYPE)

C MONITORING
      IF ((INFOFE(1:1).EQ.'T').AND.((METHOD(1:4).EQ.'FETI')
     &  .OR.(NUMSD.GT.0))) THEN
        WRITE(IFM,*)
        WRITE(IFM,*)'DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD'
        IF (NUMSD.EQ.0) THEN
          WRITE(IFM,*)'<FETI/VTCRE1> DOMAINE GLOBAL'
        ELSE
          WRITE(IFM,*)'<FETI/VTCRE1> NUMERO DE SOUS-DOMAINE: ',NUMSD
        ENDIF                             
        WRITE(IFM,*)'<FETI/VTCRE1> REMPLISSAGE OBJETS JEVEUX ',
     &        CHAMP(1:19)
        WRITE(IFM,*)'DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD'        
        WRITE(IFM,*)
      ENDIF
C FIN ------------------------------------------------------
      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/elements/vtcre1.f <==
      SUBROUTINE VTCRE1(CHAMP,NUMEDD,CLASSE,TYPE,IFM,NIV,METHOD,SDFETI,
     &                  NUMSD,NEQ)
C-----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 24/01/2005   AUTEUR BOITEAU O.BOITEAU 
C ======================================================================
C COPYRIGHT (C) 1991 - 2004  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C-----------------------------------------------------------------------
C    - FONCTION REALISEE:  CREATION DES OBJETS JEVEUX DE LA STRUCTURE
C      DE DONNEES CHAMNO. UTILITAIRE DE BAS NIVEAU LANCE PAR VTCREB.
C
C     IN  CHAMP  : K24 : NOM DU CHAM_NO A CREER
C     IN  NUMEDD : K24 : PROF_CHNO DU CHAM_NO
C     IN  CLASSE : K1  : NOM DE LA BASE SUR LAQUELLE LE CHAM_NO DOIT
C                        ETRE CREE
C     IN  TYPCE  : K1  : TYPE DES VALEURS DU CHAM_NO A CREER
C                  'R'    ==> COEFFICIENTS REELS
C                  'C'    ==> COEFFICIENTS COMPLEXES
C     IN IFM,NIV : I   : PARAMETRES POUR MONITORING.
C     IN NUMSD   : I   : NUMERO DE SOUS-DOAMINE
C     OUT METHOD,SDFETI: K24 : PARAMETRES DU SOLVEUR.
C     OUT   NEQ   : I   : INTEGER
C   -------------------------------------------------------------------
C     SUBROUTINES APPELLEES:
C       DIVERS: DISMOI,SDCHGD,UTIMSD.
C       JEVEUX:JEMARQ,JEDEMA,WKVECT,JEVEUO,JEECRA.
C
C     FONCTIONS INTRINSEQUES:
C       NONE.
C   -------------------------------------------------------------------
C     ASTER INFORMATIONS:
C       25/11/03 (OB): CREATION.
C----------------------------------------------------------------------
C RESPONSABLE BOITEAU O.BOITEAU
C CORPS DU PROGRAMME
      IMPLICIT NONE

C DECLARATION PARAMETRES D'APPELS
      CHARACTER*1  CLASSE,TYPE
      CHARACTER*24 CHAMP,NUMEDD,METHOD,SDFETI
      INTEGER      NUMSD,NEQ

C --- DEBUT DECLARATIONS NORMALISEES JEVEUX ----------------
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C --- FIN DECLARATIONS NORMALISEES JEVEUX --------------------

C DECLARATION VARIABLES LOCALES
      INTEGER      JCHAMP,JREFN,IBID,IERD,JNEQ,LCHP,NBREFN,
     &             IFM,NIV,IINF
      CHARACTER*8  K8BID
      CHARACTER*24 VALE,REFE,DESC,INFOFE

      DATA VALE/'                   .VALE'/
      DATA REFE/'                   .REFE'/
      DATA DESC/'                   .DESC'/
            
C------------------------------------------------------------------
      CALL JEMARQ()
      INFOFE='FFFFFFFF'

C ------------------------------- REFE --------------------------------
C --- AFFECTATION DES INFORMATIONS DE REFERENCE A CHAMP

C ON ETOFFE L'OBJET .REFE DU CHAMNO AVEC LE TYPE DE RESOLUTION ET LE
C NOM DE LA SD_FETI PRIS DANS LE .REFN DU NUME_DDL SOUS-JACENT

      CALL JEVEUO(NUMEDD(1:14)//'.NUME.REFN','L',JREFN)
      REFE(1:19) = CHAMP 
           
C NUME_DDL ET DONC CHAM_NO ETENDU, OUI OU NON ?      
      CALL JELIRA(NUMEDD(1:14)//'.NUME.REFN','LONMAX',NBREFN,K8BID)
      IF (NBREFN.NE.4) THEN
        IF (NIV.GE.2) WRITE(IFM,*)
     &       '<FETI/VTCRE1> NUME_DDL/CHAM_NO NON ETENDU POUR FETI',
     &       NUMEDD(1:14)//'.NUME.REFN'      
        METHOD='XXXX'
        SDFETI='XXXX'
        CALL WKVECT(REFE,CLASSE//' V K24',2,JCHAMP)                     
      ELSE
        CALL WKVECT(REFE,CLASSE//' V K24',4,JCHAMP)
        METHOD = ZK24(JREFN+2)
        SDFETI = ZK24(JREFN+3)
        ZK24(JCHAMP+2) = METHOD
        ZK24(JCHAMP+3) = SDFETI
        IF ((METHOD(1:4).EQ.'FETI').OR.(NUMSD.GT.0)) THEN
          CALL JEVEUO('&&'//SDFETI(1:17)//'.FINF','L',IINF)
          INFOFE=ZK24(IINF)
        ENDIF         
      ENDIF
      ZK24(JCHAMP) = ZK24(JREFN)
      ZK24(JCHAMP+1) = NUMEDD(1:14)//'.NUME'      
      
C ------------------------------- DESC --------------------------------
C --- AFFECTATION DES INFORMATIONS DE REFERENCE A CHAMP

      DESC(1:19) = CHAMP
      CALL WKVECT(DESC,CLASSE//' V I',2,JCHAMP)
      CALL JEECRA(DESC,'DOCU',IBID,'CHNO')
      CALL DISMOI('F','NUM_GD_SI',NUMEDD,'NUME_DDL',ZI(JCHAMP),
     &            K8BID,IERD)
      ZI(JCHAMP+1) = 1

C ------------------------------- VALE --------------------------------
C --- CREATION DE L'OBJET SIMPLE DES VALEURS
C --- TYPE DES VALEURS, LONGUEUR D'UN VECTEUR

      CALL JEVEUO(NUMEDD(1:14)//'.NUME.NEQU','L',JNEQ)
      NEQ = ZI(JNEQ)
      VALE(1:19) = CHAMP
      CALL JECREO(VALE,CLASSE//' V '//TYPE)
      CALL JEECRA(VALE,'LONMAX',NEQ,K8BID)
      CALL JEVEUO(VALE,'E',LCHP)

C --- CHANGER LA GRANDEUR
      CALL SDCHGD(CHAMP,TYPE)

C MONITORING
      IF ((INFOFE(1:1).EQ.'T').AND.((METHOD(1:4).EQ.'FETI')
     &  .OR.(NUMSD.GT.0))) THEN
        IF (NUMSD.EQ.0) THEN
          WRITE(IFM,*)'<FETI/VTCRE1> DOMAINE GLOBAL ',CHAMP(1:19)
        ELSE
          WRITE(IFM,*)'<FETI/VTCRE1> SD: ',NUMSD,' ',CHAMP(1:19)
        ENDIF                             
      ENDIF
C FIN ------------------------------------------------------
      CALL JEDEMA()
      END
